aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichał Górny <mgorny@gentoo.org>2016-12-19 09:30:28 +0100
committerMichał Górny <mgorny@gentoo.org>2016-12-19 09:31:03 +0100
commitcfdfcda718782208d2717dfbcddb16dfc453d822 (patch)
tree9ad1f35f3099acb276f85eb3c6226fa493cc59a9 /datestamp.sh
parentrsync-gen: declare new vars for changelog module. (diff)
downloadmastermirror-scripts-cfdfcda718782208d2717dfbcddb16dfc453d822.tar.gz
mastermirror-scripts-cfdfcda718782208d2717dfbcddb16dfc453d822.tar.bz2
mastermirror-scripts-cfdfcda718782208d2717dfbcddb16dfc453d822.zip
Update STAGEDIR, FINALDIR in remaining scripts
Fixes: 931a49ce1da1063 ("rsync-gen: be clear about variable purposes.")
Diffstat (limited to 'datestamp.sh')
-rwxr-xr-xdatestamp.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/datestamp.sh b/datestamp.sh
index 0879758..5adad9f 100755
--- a/datestamp.sh
+++ b/datestamp.sh
@@ -5,14 +5,14 @@ umask 022 # ensure globally readable perms on new files for rsyncd
source /usr/local/bin/mastermirror/rsync-gen.vars
# The only time ${STAGEDIR}/metadata should not exist is when rsync-gen.sh
# hasn't ran even once yet
-if [[ -d ${STAGEDIR}/metadata ]]; then
- /bin/date -u '+%s %c' > ${STAGEDIR}/metadata/timestamp.x.tmp
- /bin/mv ${STAGEDIR}/metadata/timestamp.x.tmp ${STAGEDIR}/metadata/timestamp.x
+if [[ -d ${STAGEDIR_repo_gentoo}/metadata ]]; then
+ /bin/date -u '+%s %c' > ${STAGEDIR_repo_gentoo}/metadata/timestamp.x.tmp
+ /bin/mv ${STAGEDIR_repo_gentoo}/metadata/timestamp.x.tmp ${STAGEDIR_repo_gentoo}/metadata/timestamp.x
fi
-if [[ -d ${FINALDIR}/metadata ]]; then
- /bin/date -R -u > ${FINALDIR}/metadata/timestamp.chk.tmp
- /bin/mv ${FINALDIR}/metadata/timestamp.chk.tmp ${FINALDIR}/metadata/timestamp.chk
+if [[ -d ${FINALDIR_repo_gentoo}/metadata ]]; then
+ /bin/date -R -u > ${FINALDIR_repo_gentoo}/metadata/timestamp.chk.tmp
+ /bin/mv ${FINALDIR_repo_gentoo}/metadata/timestamp.chk.tmp ${FINALDIR_repo_gentoo}/metadata/timestamp.chk
fi
@@ -5,14 +5,14 @@ umask 022 # ensure globally readable perms on new files for rsyncd
source /usr/local/bin/mastermirror/rsync-gen.vars
-# The only time ${STAGEDIR}/metadata should not exist is when rsync-gen.sh
+# The only time ${STAGEDIR_repo_gentoo}/metadata should not exist is when rsync-gen.sh
# hasn't ran even once yet